.. _async_dsl:

Async DSL
=========

.. py:module:: elasticsearch.dsl
   :no-index:

Search
------
.. autoclass:: AsyncSearch
   :inherited-members:
   :members:

Multi-Search
------------
.. autoclass:: AsyncMultiSearch
   :inherited-members:
   :members:

Document
--------
.. autoclass:: AsyncDocument
   :inherited-members:
   :members:

Index
-----
.. autoclass:: AsyncIndex
   :inherited-members:
   :members:

Mapping
-------
.. autoclass:: AsyncMapping
   :inherited-members:
   :members:

Faceted Search
--------------
.. autoclass:: AsyncFacetedSearch
   :inherited-members:
   :members:

Update by Query
---------------
.. autoclass:: AsyncUpdateByQuery
   :inherited-members:
   :members:
